function [Relerrs,z] = QTAF1D(y,x,d,m,eta,gamma,npower_iter,iter,Amatrix)

%% QTAF algorithm

%% Initialization
z0 = randn(d,1) + randn(d,1) * qi +  randn(d,1) * qj +  randn(d,1) * qk; 
z0 = z0 / norm(z0);    % Initial guess
normest = sqrt(sum(y(:)) / numel(y(:)));    % Estimate norm to scale eigenvector

Arnorm  = sqrt(sum(abs(Amatrix).^2, 2)); % norm of rows of Amatrix
ymag    = sqrt(y);
ynorm   = ymag ./ (Arnorm .* normest);

%% finding the angle of inner product

Anorm = Amatrix ./ Arnorm;
[ysort, ~] = sort(ynorm, 'ascend');
ythresh    = ysort(round(m / (6/5))); % 6/5 the orthogonality-promoting initialization parameter
ind        = (abs(ynorm) >= ythresh);

for tt = 1:npower_iter                   % Truncated power iterations
    z0 = Anorm' * (ind .* (Anorm * z0));
    z0 = z0 /norm(z0);
end

z          = normest * z0;                   % Apply scaling
Relerrs = norm(x - z*sign(z' * x) ) / norm(x); % Initial rel. error

%% QTAF update
for t = 1:iter
    
    Az    = Amatrix * z; %A(z);
    ratio = abs(Az) ./ ymag;
    yz    = ratio > 1 / (1 +  gamma);
    grad = (1/(2*m)) * Amatrix' * (Az .* yz .* (1 - ymag./abs(Az)));
    z = z - eta * grad;
    Relerrs = [Relerrs; norm(x - z* sign(z' * x) ) / norm(x)];
end
end


